Runs the package's tests, examples, vignettes and full check, and lists files that were created or modified outside the check directory. CRAN raises a NOTE for "non-standard things in the check directory". Wraps check_clean_userspace().

audit_userspace(pkg = ".", check_output = tempfile("dircheck"))

Arguments

pkg

Path to the package to audit.

check_output

Where to store check outputs (defaults to a tempfile).

Value

A tibble of leaked files with columns source, problem, where, file.

Examples

if (FALSE) { # \dontrun{
pkg <- create_example_pkg()
audit_userspace(pkg)
} # }