Deprecated: use audit_tags() instead
find_missing_tags(
package.dir = ".",
roclets = NULL,
load_code = NULL,
clean = FALSE
)Location of package top level directory. Default is working directory.
Character vector of roclet names to use with package.
The default, NULL, uses the roxygen roclets option,
which defaults to c("collate", "namespace", "rd").
A function used to load all the R code in the package
directory. The default, NULL, uses the strategy defined by
the load roxygen option, which defaults to load_pkgload().
See load for more details.
If TRUE, roxygen will delete all files previously
created by roxygen before running each roclet.
See audit_tags().